<?php

namespace App\Services;

use Square\SquareClient;
use Square\Models\CreatePaymentRequest;
use Square\Models\Money;
use Square\Models\CreatePaymentResponse;
use Square\Exceptions\ApiException;

class SquarePaymentService
{
    private $client;

    public function __construct()
    {
        $this->client = new SquareClient([
            'accessToken' => env('SQUARE_ACCESS_TOKEN'),
            'environment' => 'sandbox' // Change to 'production' for live transactions
        ]);
    }

    /**
     * Process a payment using Square.
     */
    public function processPayment($nonce, $amount, $currency = 'USD')
    {
        $paymentsApi = $this->client->getPaymentsApi();
        $body = new CreatePaymentRequest(
            $nonce, // nonce from Square's front-end (e.g. Square.js)
            env('SQUARE_LOCATION_ID'),
            new Money($amount* 100, $currency) // Amount in cents
        );

        try {
            $response = $paymentsApi->createPayment($body);
            if ($response->isSuccess()) {
                return $response->getResult();
            } else {
                return $response->getErrors();
            }
        } catch (ApiException $e) {
            return $e->getMessage();
        }
    }
}
